======================
t-nextgen
======================

A Python library providing seamless methods to interact with NextGen application, enabling automation and integration for enhanced workflow efficiency
